# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Validate method/function parameters
Name:		perl-Params-Validate
Version:	1.31
Release:	1.%{__distinit}%{__distvers}
# One file is GPL-1.0-or-later OR Artistic-1.0-Perl (c/ppport.h)
License:	Artistic-2.0 and (GPL-1.0-or-later OR Artistic-1.0-Perl)
URL:		https://metacpan.org/release/Params-Validate
Source0:	https://cpan.metacpan.org/modules/by-module/Params/Params-Validate-%{version}.tar.gz
Patch0:		Params-Validate-1.31-spelling.patch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::CBuilder)
BuildRequires:	perl(lib)
BuildRequires:	perl(Module::Build) >= 0.42.27
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Module::Implementation) >= 0.04
BuildRequires:	perl(Scalar::Util) >= 1.10
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
BuildRequires:	perl(XSLoader)
# Test Suite
BuildRequires:	perl(base)
BuildRequires:	perl(Devel::Peek)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(overload)
BuildRequires:	perl(Test::Fatal)
BuildRequires:	perl(Test::More) >= 0.47
BuildRequires:	perl(Test::Requires)
BuildRequires:	perl(Tie::Array)
BuildRequires:	perl(Tie::Hash)
BuildRequires:	perl(Tie::StdArray)
BuildRequires:	perl(Tie::StdHash)
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Prereqs)
BuildRequires:	perl(Readonly) >= 1.03
BuildRequires:	perl(Test::Taint) >= 0.02
# Author/Release Tests
%if 0%{!?perl_bootstrap:1}
%if 0%{?fedora} > 23 || 0%{?rhel} > 7
BuildRequires:	glibc-langpack-en
%endif
BuildRequires:	perl(blib)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Pod::Wordlist)
BuildRequires:	perl(Scalar::Util) >= 1.20
BuildRequires:	perl(Test::CPAN::Changes)
BuildRequires:	perl(Test::CPAN::Meta::JSON)
BuildRequires:	perl(Test::EOL)
BuildRequires:	perl(Test::LeakTrace) >= 0.15
BuildRequires:	perl(Test::Mojibake)
BuildRequires:	perl(Test::NoTabs)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Spelling) >= 0.12, hunspell-en
BuildRequires:	perl(Test::Synopsis)
%endif
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Don't "provide" private Perl libs
%global __provides_exclude ^XS\\.so

%description
The Params::Validate module allows you to validate method or function
call parameters to an arbitrary level of specificity. At the simplest
level, it is capable of validating the required parameters were given
and that no unspecified additional parameters were passed in. It is
also capable of determining that a parameter is of a specific type,
that it is an object of a certain class hierarchy, that it possesses
certain methods, or applying validation callbacks to arguments.

%prep
%setup -q -n Params-Validate-%{version}

# Extra stopwords for the POD spelling test
%patch0

%build
perl Build.PL --installdirs=vendor --optimize="%{optflags}"
./Build

%install
./Build install --destdir=%{buildroot} --create_packlist=0
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
./Build test

# Release tests
%if 0%{!?perl_bootstrap:1}
LC_ALL=en_US ./Build test --test_files="$(echo $(find xt/ -name '*.t'))"
%endif

%files
%license LICENSE
%doc Changes CODE_OF_CONDUCT.md CONTRIBUTING.md README.md TODO
%{perl_vendorarch}/Params/
%{perl_vendorarch}/auto/Params/
%{_mandir}/man3/Params::Validate.3*

%changelog
* Sun Oct 23 2022 Paul Howarth <paul@city-fan.org> - 1.31-1
- Update to 1.31
  - Include Devel::PPPort 3.68 for compatibility with Perls ≤ 5.8.5 (GH#25)
- Use SPDX-format license tag

* Thu Jun  2 2022 Paul Howarth <paul@city-fan.org> - 1.30-6
- Perl 5.36 rebuild

* Mon May 24 2021 Paul Howarth <paul@city-fan.org> - 1.30-3
- Perl 5.34 rebuild

* Mon Oct 19 2020 Paul Howarth <paul@city-fan.org> - 1.30-1
- Update to 1.30
  - Support pure Perl builds via the standard incantation of
    'perl Build.PL --pureperl_only'; the '--pp' flag is still supported (GH#17)

* Mon Jun 29 2020 Paul Howarth <paul@city-fan.org> - 1.29-13
- Perl 5.32 rebuild

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 1.29-10
- Perl 5.30 rebuild

* Fri Mar  8 2019 Paul Howarth <paul@city-fan.org> - 1.29-9
- Work around mock locale issues by adding buildreq glibc-langpack-en when
  running extra tests

* Thu Aug 16 2018 Paul Howarth <paul@city-fan.org> - 1.29-8
- Correct license tag (#1376845)

* Thu Jun 28 2018 Paul Howarth <paul@city-fan.org> - 1.29-6
- Perl 5.28 rebuild

* Thu Mar  1 2018 Paul Howarth <paul@city-fan.org> - 1.29-5
- Arch-specific package using Module::Build needs to use ExtUtils::CBuilder
  (https://bugzilla.redhat.com/show_bug.cgi?id=1547165#c7)

* Mon Aug  7 2017 Paul Howarth <paul@city-fan.org> - 1.29-3
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Mon Jun 12 2017 Paul Howarth <paul@city-fan.org> - 1.29-1
- Update to 1.29
  - Fixes for MSVC compilation (GH#15)
- Update patches as needed

* Sun May  7 2017 Paul Howarth <paul@city-fan.org> - 1.28-1
- Update to 1.28
  - Removed the broken Makefile.PL that was accidentally being shipped with
    this distro since 1.26

* Sun Apr 30 2017 Paul Howarth <paul@city-fan.org> - 1.27-1
- Update to 1.27
  - When more than one required parameter is missing, the list of missing
    parameters in the error message is sorted by name (GH#14)
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88
  - BR: perl-devel unconditionally
  - Spell checker is always hunspell now

* Fri Oct  7 2016 Paul Howarth <paul@city-fan.org> - 1.26-1
- Update to 1.26
  - Reverted to Module::Build; the use of EUMM in 1.25 broke Windows build
- Update patches as needed

* Mon Sep 26 2016 Paul Howarth <paul@city-fan.org> - 1.25-1
- Update to 1.25
  - Switch to ExtUtils::MakeMaker flow
- Update patches as needed

* Thu Jul 28 2016 Paul Howarth <paul@city-fan.org> - 1.24-3
- Fix FTBFS when perl is not in the minimal buildroot

* Tue May 17 2016 Paul Howarth <paul@city-fan.org> - 1.24-2
- BR: perl-generators where available

* Mon May  9 2016 Paul Howarth <paul@city-fan.org> - 1.24-1
- Update to 1.24
  - Author tests are no longer in t/, which makes running tests for non-authors
    faster (CPAN RT#113063)
- Explicitly run the extra tests where possible
- Update patches as needed

* Tue Mar 29 2016 Paul Howarth <paul@city-fan.org> - 1.23-1
- Update to 1.23
  - Fixed some Perl stack corruption bugs (GH#8)
  - Fixed tests with Carp 1.01, shipped with Perl 5.8.3 (CPAN RT#113318)
- Simplify find command using -empty and -delete
- Update patches as needed
- Drop now-redundant provides filter

* Sun Feb 14 2016 Paul Howarth <paul@city-fan.org> - 1.22-1
- Update to 1.22
  - Fixed a bug when a callback failed but did not die; the resulting error
    message had a pointless colon in it (CPAN RT#111036)
  - Made the pure Perl version use Carp's croak rather than confess - the XS
    version has never included a stack trace in errors; you can use the on_fail
    setting to get a stack trace if you prefer (CPAN RT#111036)
  - The pure Perl code now uses "(unknown)" when it cannot determine the sub
    that failed, instead of "N/A" (CPAN RT#111036)
  - Documented the PARAMS_VALIDATE_IMPLEMENTATION environment variable
    (CPAN RT#111035)
- Explicitly BR: perl-devel, needed for EXTERN.h
- Update patches as needed

* Sun Jul 19 2015 Paul Howarth <paul@city-fan.org> - 1.21-1
- Update to 1.21
  - Attribute::Params::Validate is now in its own distro
- Update patches as needed

* Mon Jun 29 2015 Paul Howarth <paul@city-fan.org> - 1.20-1
- Update to 1.20
  - Fixed a bug with stack handling in the XS code (GH#5)
  - Fixed use of inlining in the XS code to work when "gcc -std=c89" is
    specified (GH#6)
  - Previously, Params::Validate would eagerly stringify all values it was
    validating, even though this stringification was only needed for error
    messages that are used when a parameter fails; for objects that overload
    stringification and do real work, this added an unnecessary slowdown, so
    stringification is now delayed until it is needed (CPAN RT#105326)
- Update patches as needed

* Fri Jun 26 2015 Paul Howarth <paul@city-fan.org> - 1.19-1
- Update to 1.19
  - Fixed an uninitialized value warning from the pure Perl implementation
    under 5.8.8 (CPAN RT#105198)
- Update patches as needed

* Sat Feb 14 2015 Paul Howarth <paul@city-fan.org> - 1.18-1
- Update to 1.18
  - We no longer attempt to save and restore an existing $SIG{__DIE__} hook
    before calling a validation callback; this used undocumented black magic
    poking at the Perl interpreter guts, which seems to cause sporadic
    segfaults (CPAN RT#102112)
- Update patches as needed

* Fri Jan  9 2015 Paul Howarth <paul@city-fan.org> - 1.17-1
- Update to 1.17
  - Callbacks can now die to provide a custom error message or exception
    object (CPAN RT#95701); this will allow MooseX::Params::Validate to use
    messages provided by the type object
  - Simplified how we localize $@ in the XS code and fixed error with Perls
    compiled with -DDEBUGGING (CPAN RT#101416)
- Classify buildreqs by usage
- Unbundle Attribute::Handlers version patch from old Test::More patch
- Update other patches as needed

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 1.13-4
- Use %%license where possible

* Mon Jun 30 2014 Paul Howarth <paul@city-fan.org> - 1.13-1
- Update to 1.13
  - Fixes for MSVC compilation
    (https://github.com/autarch/Params-Validate/pull/1)
  - Temporarily skip tests that use Readonly with Readonly 1.50+ until various
    bugs are worked out in Readonly
- Update patch for building with old Test::More versions
- BR: perl(Test::CPAN::Changes) unconditionally
- Drop now-redundant BR: perl(Readonly::XS)

* Mon May 12 2014 Paul Howarth <paul@city-fan.org> - 1.10-1
- Update to 1.10
  - Require Readonly 1.03+ and Scalar::Util 1.20 for testing with Readonly
    (CPAN RT#95402)
- Update patch for building with old Test::More versions

* Tue May  6 2014 Paul Howarth <paul@city-fan.org> - 1.09-2
- Run the release tests only if we have Scalar::Util ≥ 1.20

* Sun May  4 2014 Paul Howarth <paul@city-fan.org> - 1.09-1
- Update to 1.09
  - A call to validate() where the spec was a reference to a Readonly hash
    would segfault (CPAN RT#80572)
  - When using the XS implementation, attempting to validate parameters with
    tainted values would cause an "Insecure dependency in eval_sv() while
    running with -T switch" exception from Perl *if the validation failed*;
    this is fixed, but only for Perl 5.14+ - older Perls do not include the
    necessary XS API (CPAN RT#70174)
  - Fixed some potential segfaults from the XS implementation (CPAN RT#50412);
    however, the XS code in general is pretty crufty and tends to assume that
    values which could be NULL aren't
  - Fixed bad example of state() in POD (CPAN RT#80250)
- Update patch for building with old Test::More versions
- Drop %%defattr, redundant since rpm 4.4
- Temporarily avoid the release tests on old perls as the
  t/release-pp-23-readonly.t test fails (CPAN RT#80572)

* Thu Jan 16 2014 Paul Howarth <paul@city-fan.org> - 1.08-4
- Don't run the release tests when bootstrapping

* Tue Jul 23 2013 Paul Howarth <paul@city-fan.org> - 1.08-3
- Perl 5.18 rebuild

* Wed Jun 12 2013 Paul Howarth <paul@city-fan.org> - 1.08-1
- Update to 1.08
  - The handling of defaults in the XS version of validate_pos was broken: the
    defaults were simply pushed into the returned array, rather than being
    explicitly stored in the right index based on the order of the specs passed
    to validate_pos() (CPAN RT#83780)
- Update patches

* Mon Oct 29 2012 Paul Howarth <paul@city-fan.org> - 1.07-1
- Update to 1.07
  - Params::Validate's XS implementation would overwrite $@ when validation
    subs were called (CPAN RT#80124)
  - The use of state in the POD was broken; it only works with scalars
    (CPAN RT#80250)
- Update patch for building with old Test::More versions

* Mon Jul  9 2012 Paul Howarth <paul@city-fan.org> - 1.06-3
- BR: perl(Attribute::Handlers), perl(Devel::Peek), perl(Exporter),
  perl(File::Spec), perl(File::Temp), perl(lib) and perl(Test::More)
- Update provides filter for rpm ≥ 4.9
- Drop redundant BR: perl(Pod::Man)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use %%{_fixperms} macro rather than our own chmod incantation
  - Spelling dictionary is always aspell-en

* Tue Feb 21 2012 Paul Howarth <paul@city-fan.org> - 1.06-1
- Update to 1.06
  - Shut up warnings when XS is loaded on older 5.8.x Perl versions (CPAN RT#74742)
- Always build XS version

* Thu Feb  9 2012 Paul Howarth <paul@city-fan.org> - 1.05-1
- Update to 1.05
  - Use the latest Module::XSOrPP dzil plugin to generate a saner Build.PL
  - The XS code had a code path where it could pass the contents of a Perl
    variable as the first argument to the XS croak() subroutine; this subroutine
    is like printf(), and should receive a format string as its first
    argument, which can lead to segfaults on some systems (CPAN RT#74777)
- BR: perl(Module::Implementation) ≥ 0.04
- Update patch for building with old Test::More versions

* Tue Feb  7 2012 Paul Howarth <paul@city-fan.org> - 1.03-1
- Update to 1.03
  - The previous release never loaded the XS implementation, even if it had
    been compiled
  - With newer versions of Perl, the pure Perl implementation treated regexp
    objects differently than the XS implementation; they should be treated as
    belonging to the SCALARREF type for backwards compatibility
  - These two bugs combined managed to break the test suites of a number of
    modules on CPAN; this release should fix them
  - This release uses Module::Implementation to handle loading the XS or pure
    Perl implementation of Params::Validate
- BR: perl(Module::Implementation) and perl(Test::Fatal)
- Update patch for building with old Test::More versions
- Don't build the XS version with perl < 5.8.8 as it spews warnings
  (CPAN RT#74742)

* Mon Feb  6 2012 Paul Howarth <paul@city-fan.org> - 1.01-1
- Update to 1.01
  - The generated Build.PL detects whether or not the machine it's run on has a
    working compiler, and disables XS automatically if it doesn't
    (CPAN RT#44719)
- Re-enable Pod::Coverage test since it's working again
- BR: perl(Scalar::Util) ≥ 1.10
- Drop patch for perl 5.8.0 as we no longer support it
- Update patches

* Sat Jul 23 2011 Paul Howarth <paul@city-fan.org> - 1.00-3
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Sat Jun 11 2011 Paul Howarth <paul@city-fan.org> - 1.00-1
- Update to 1.00
  - Fix documentation indexing on search.cpan.org (CPAN RT#68756)
- Disable failing Pod::Coverage test

* Sat May 28 2011 Paul Howarth <paul@city-fan.org> - 0.99-1
- Update to 0.99
  - The metadata file - META.{json,yml} - had references to a different distro
    because of a copy and paste error (CPAN RT#68514)
- Update stopwords patch

* Tue Apr 26 2011 Paul Howarth <paul@city-fan.org> - 0.98-2
- Test::Spelling now available everywhere

* Sat Apr 23 2011 Paul Howarth <paul@city-fan.org> - 0.98-1
- Update to 0.98
  - Attribute::Params::Validate's $VERSION regressed in 0.96; it is now
    manually set to 1.07

* Wed Apr 20 2011 Paul Howarth <paul@city-fan.org> - 0.97-1
- Update to 0.97
  - The XS version of the code always called Carp::confess, regardless of
    whether you provided your own on_fail callback (CPAN RT#66359)
  - There were a couple of spots that called eval without localizing $@ first
    (CPAN RT#58087)
  - Include (but disabled for now) parameter spec validation (CPAN RT#57831)
  - Lots of little pod fixes (CPAN RT#61002)
  - This module now requires Perl 5.8.1
  - Switched to version 2.0 of the Artistic License
- Make %%summary be useful
- Add patch with extra stopwords for the new POD spelling test
- Add patch to support building with Test::More < 0.88
- Add patch to support use with Perl 5.8.0
- Add new buildreqs perl(Test::CPAN::Changes), perl(Test::EOL),
  perl(Test::NoTabs), perl(Test::Spelling) and aspell-en
- Drop now-unused buildreq perl(Test::Kwalitee)
- Manually provide a versioned perl(Params::Validate) if necessary

* Wed Mar 23 2011 Paul Howarth <paul@city-fan.org> - 0.95-4
- BR: perl(Test::Kwalitee)
- Nobody else likes macros for commands

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 0.95-3
- Rebuild for perl 5.12.1 in Rawhide

* Wed Jun  2 2010 Paul Howarth <paul@city-fan.org> - 0.95-2
- Fix dist tag for RHEL-6 Beta

* Tue Feb 16 2010 Paul Howarth <paul@city-fan.org> - 0.95-1
- Update to 0.95 (skip problematic t/29-taint-mode.t entirely)
- Fix filter for unversioned provide

* Thu Jan 21 2010 Paul Howarth <paul@city-fan.org> - 0.94-2
- Import from Fedora

* Tue Dec 15 2009 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.94-1
- Upstream update
- Reflect upstream having reworked author tests to using AUTHOR_TESTING=1

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.92-2
- Rebuild against perl 5.10.1

* Mon Nov 23 2009 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.92-1
- Upstream update
- Switch to Build.PL
- Disable IS_MAINTAINER test

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.91-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.91-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Jun 10 2008 Ralf Corsépius <rc040203@freenet.de> - 0.91-1
- Upstream update
- Conditionally activate IS_MAINTAINER tests

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.89-4
- Rebuild for perl 5.10 (again)

* Sun Feb 10 2008 Ralf Corsépius <rc040203@freenet.de> - 0.89-3
- Rebuild for gcc43

* Tue Jan 15 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.89-2
- Rebuild for new perl

* Tue Nov 13 2007 Ralf Corsépius <rc040203@freenet.de> - 0.89-1
- Upstream update

* Thu Sep 06 2007 Ralf Corsépius <rc040203@freenet.de> - 0.88-3
- Update license tag

* Wed Aug 22 2007 Ralf Corsépius <rc040203@freenet.de> - 0.88-2
- Mass rebuild

* Mon Mar 12 2007 Ralf Corsépius <rc040203@freenet.de> - 0.88-1
- BR: perl(ExtUtils::MakeMaker)
- Upstream update

* Sat Jan 20 2007 Ralf Corsépius <rc040203@freenet.de> - 0.87-1
- Upstream update

* Tue Sep 05 2006 Ralf Corsépius <rc040203@freenet.de> - 0.86-2
- Mass rebuild

* Sun Aug 13 2006 Ralf Corsépius <rc040203@freenet.de> - 0.86-1
- Upstream update

* Wed Jun 28 2006 Ralf Corsépius <rc040203@freenet.de> - 0.85-1
- Upstream update

* Mon Jun 05 2006 Ralf Corsépius <rc040203@freenet.de> - 0.84-1
- Upstream update

* Sun May 21 2006 Ralf Corsépius <rc040203@freenet.de> - 0.82-1
- Upstream update

* Tue Apr 04 2006 Ralf Corsépius <rc040203@freenet.de> - 0.81-1
- Upstream update

* Mon Feb 20 2006 Ralf Corsépius <rc040203@freenet.de> - 0.80-2
- Rebuild

* Wed Feb 01 2006 Ralf Corsépius <rc040203@freenet.de> - 0.80-1
- Upstream update

* Sat Jan 14 2006 Ralf Corsépius <rc040203@freenet.de> - 0.79-1
- Upstream update
- BR perl(Readonly), perl(Readonly::XS)

* Sun Aug 14 2005 Ralf Corsepius <ralf@links2linux.de> - 0.78-2
- Spec file cleanup

* Wed Aug 10 2005 Ralf Corsepius <ralf@links2linux.de> - 0.78-1
- FE submission
